#
# benchmark.py
#
# Copyright (c) 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Bees Software.
#
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#

# Class used to communicate with the Benchmark JSI handler.

from jsi.message import *
from jsi.channel import *
from jsi.messageError import *

class Benchmark:
    def __init__(self, chan, capability):
        self.channel = chan
        self.capability = capability
        self.msg = Message()
        self.msg.pushSpecifier("eventChannel", self.capability)
        self.msg.pushSpecifier("user")

    def send(self):
        self.msg.reverseSpecifiers()
        what = self.msg.getWhat()
        buf = self.msg.flatten()
        self.msg.clear()
        self.msg.pushSpecifier("eventChannel", self.capability)
        self.msg.pushSpecifier("user")
        self.channel.send(buf)
        if what == JSI_SHUTDOWN:
            return
        else:
            buf = self.channel.recv()
            reply = Message()
            reply.unflatten(buf)
            if reply.getWhat() == JSI_ERROR:
                raise MessageError(reply)
            else:
                return reply

    def shutdown(self):
        self.msg.setWhat(JSI_SHUTDOWN)
        self.send()

    def doSendTest(self, size=0, cycles=100000):
        self.msg.setWhat(JSI_EXECUTE_PROPERTY)
        self.msg.pushSpecifier("send")
        self.msg.add("size", str(size))
        self.msg.add("cycles", str(cycles))
        reply = self.send()
        retval = {
            "start" : reply.find("start"),
            "last" : reply.find("last"),
            "packetCount" : reply.find("packetCount"),
            "pps" : reply.find("pps"),
            }
        return retval
