#
# neighbor.py
#
# Copyright (c) 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Bees Software.
#
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#

from bees import *

class Neighbor:
    def __init__(self, bees, name=""):
        self.bees = bees
        if not name == "":
            self.bees.msg.pushSpecifier("neighbor", name)

    def getInterfaceByAddress(self, address):
        self.bees.msg.setWhat(JSI_EXECUTE_PROPERTY)
        self.bees.msg.pushSpecifier("neighbor")
        self.bees.msg.pushSpecifier("getInterfaceByAddress")
        self.bees.msg.add("address", address)
        reply = self.bees.send()
        return reply.find("result")

    def create(self, name, ips, ias, ops, oas):
        self.bees.msg.setWhat(JSI_CREATE_PROPERTY)
        self.bees.msg.pushSpecifier("neighbor")
        self.bees.msg.add("name", name)
        self.bees.msg.add("incomingProtocolSpec", ips)
        self.bees.msg.add("incomingAddressSpec", ias)
        self.bees.msg.add("outgoingProtocolSpec", ops)
        self.bees.msg.add("outgoingAddressSpec", oas)
        self.bees.msg.add("permission", "capsule=read,write")
        self.bees.msg.add("permission", "incomingProtocolSpec=read")
        self.bees.msg.add("permission", "incomingAddressSpec=read")
        self.bees.msg.add("permission", "outgoingProtocolSpec=read")
        self.bees.msg.add("permission", "outgoingAddressSpec=read")
        reply = self.bees.send()
        return string.atoi(reply.find("result"))

    def get(self):
        self.bees.msg.setWhat(JSI_GET_PROPERTY)
        reply = self.bees.send()
        return {
            "incomingProtocolSpec" : reply.find("incomingProtocolSpec"),
            "incomingAddressSpec" : reply.find("incomingAddressSpec"),
            "outgoingProtocolSpec" : reply.find("outgoingProtocolSpec"),
            "outgoingAddressSpec" : reply.find("outgoingAddressSpec"),
            }

    def getIncomingProtocolSpec(self):
        self.bees.msg.setWhat(JSI_GET_PROPERTY)
        self.bees.msg.pushSpecifier("incomingProtocolSpec")
        reply = self.bees.send()
        return reply.find("result")

    def getIncomingAddressSpec(self):
        self.bees.msg.setWhat(JSI_GET_PROPERTY)
        self.bees.msg.pushSpecifier("incomingAddressSpec")
        reply = self.bees.send()
        return reply.find("result")

    def getOutgoingProtocolSpec(self):
        self.bees.msg.setWhat(JSI_GET_PROPERTY)
        self.bees.msg.pushSpecifier("outgoingProtocolSpec")
        reply = self.bees.send()
        return reply.find("result")

    def getOutgoingAddressSpec(self):
        self.bees.msg.setWhat(JSI_GET_PROPERTY)
        self.bees.msg.pushSpecifier("outgoingAddressSpec")
        reply = self.bees.send()
        return reply.find("result")

    def __str__(self):
        self.bees.msg.setWhat(JSI_GET_PROPERTY)
        reply = self.bees.send()
        return ("Neighbor[incomingProtocolSpec="
                + reply.find("incomingProtocolSpec")
                + "; incomingAddressSpec="
                + reply.find("incomingAddressSpec")
                + "; outgoingProtocolSpec="
                + reply.find("outgoingProtocolSpec")
                + "; outgoingAddressSpec="
                + reply.find("outgoingAddressSpec")
                + "]")
