#
# beesTest.py
#
# Copyright (c) 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Bees Software.
#
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#

import os
import time
import socket

from jsi.channel import *
from bees.bees import *
from bees.tools.beesUtil import *

chan = jsiConnectChannelTo(os.environ["JSIDST"], retries = 15)

node = Bees(chan)

node.node().create("node")
node.logger().create("logger.INFO", "", "info", domainPrefix="no")
node.logger().create("logger.DBG", "", "debug", domainPrefix="no")
node.meter().create("cpu-meter",
                    "machine-account",
                    countPermissions={
    "cpu.shares" : 1000,
    "cpu.threads" : 5,
    })
node.meter().create("mem-meter",
                    "machine-account",
                    countPermissions={
    "mem.pages" : 100,
    })
node.meter().create("cap-meter",
                    "machine-account",
                    countPermissions={
    "capability.memory" : 32 * 1024,
    })
createClasses(node, "cs", [
    "bees.core.TestBDomain",
    "bees.tests.Test",
    ])
createPackages(node, "ps", [
    "bees.tests",
    ])
node.bdomainRegister().create("primary")

def runAntsTest(args, named={}, extras=[], initial=[]):
    try:
        initial.extend([
            "cpu-meter",
            "mem-meter",
            ])
        node.bdomainRegister("primary").bdomain().create("ec",
                                                         "bees.core.TestBDomain",
                                                         args=args,
                                                         capabilities=initial,
                                                         countPermissions={
            "cpu.shares" : 100,
            "cpu.threads" : 2,
            "mem.pages" : 50,
            })
        if not named.has_key("node"):
            named["node"] = "node"
        if not named.has_key("logger"):
            named["logger"] = "logger.DBG"
        extras.extend(["cs", "ps"])
        node.eventChannel("ec").passCapability(named=named, extras=extras)
        node.bdomainRegister("primary").bdomain("ec").waitFor()
    except MessageError, e:
        print `e`
