#
# capability-create-help.py
#
# Copyright (c) 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Bees Software.
#
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#

import os
import sys
import time
import beesPageTemplate

config = {
    "title" : "Capability Create Help",
    "time" : time.ctime(os.stat(sys.argv[0])[8]),
    "help-file" : "root-help.html",
    }

body = """
<h2>Capability Create Help</h2>
<p>

Creating a capability is a matter of selecting the type of object to create and
filling out its parameters.  Every has capability atleast two required
parameters:

<ul>
<li>Destination directory - The directory in the kernel capability tree that
the new capability should be listed under.
<li>Name - The name of the capability to create.
</ul>

<h4>Directory</h4>

Creates a new directory for storing capabilities.

<h4>Envelope</h4>

Creates a new envelope for a given capability.  You'll want to create an
envelope if you want to pass a capability to a domain with reduced permissions.
For example, instead of creating multiple file capabilities with different sets
of permissions, you can create an envelope wrapping the file, change its
permissions and pass that to the protocol flow.

<h4>Classes and Packages</h4>

The class loader built into Bees controls access to system classes by
designating certain packages as belonging to the "system" and then individually
exporting them to the domain.  The "classes" and "packages" types are used to
control this behavior.  By passing a package capability to a domain, the class
loader will be notified that the package belongs to the system and any classes
within this package should be loaded by the shared system class loader.  Then,
when a class capability is passed to a domain, any code using the class will be
able to complete linking.  For example, to grant a domain access to the
<code>kaffe.sensors.Sensor</code> class, you would need to pass it a
"kaffe.sensors" package capability and a "kaffe.sensors.Sensor" capability.

<h4>Neighbor</h4>

Neighbor capabilities grant access to a domain for communicating with another
Bees node.  These channels are point to point, they fully specify the source
and destination of a packet, there is no way for a domain to address another
node using this type of capability.  Typically, you should not have to create
any neighbors since the "Discovery" protocol will find any Bees nodes on the
local LAN.  However, you will need to create one if you want to peer with a
node that is not directly connected.

Currently, there are three ways to specify the local and remote addresses that
make up a neighbor object.

<ul>
<li>UDP - Create a neighbor that communicates using the UDP protocol.
<li>Ethernet - Create a neighbor that communicates using raw Ethernet.
<i>Note</i>:  The address values entered here must be the NodeOS style hex
string and not the standard colon separated style.
<li>Generic - Create a neighbor that communicates using the given NodeOS style
protocol and address specs.
</ul>

<h4>Version String</h4>

<h4>Logger</h4>

A Logger capability is used to log messages with a given prefix to an output
capability.  For the most part, this is similar to an append only file, except,
you can force the messages to have a certain prefix, and you can set the
minimum "severity" level of messages that get printed.  The parameters for a
Logger capability are as follows:

<ul>
<li>Output - The name of a file or console capability that can be used as the
destination for any messages.
<li>Prefix - The prefix to prepend to each message.
<li>Level - The minimum severity level for message output.  Selecting
"Debug" will only print all messages and selecting "Emergency" will only print
messages when the domain is running into real big problems.
</ul>

<h4>Key Pair</h4>

Cryptographic keys are wrapped as capabilities so that they can be passed
around easily without having to worry about any private key material being
leaked.  Creating a key pair for a public key algorithm is simply a matter of
filling out the following parameters and having some patience waiting for the
request to complete.  <i>Note</i>: Unlike the other capabilities, creating a
key pair results in a new directory with "public" and "private" members
corresponding to each type of key.

<ul>
<li>Algorithm - The cryptographic algorithm to use.  This parameters depends on
the installed system, but most should have DSA and RSA implementations.
<li>Key Size - The bit size of the keys.  This value is dependent on the
algorithm used.
</ul>

<h4>File System</h4>

A file system capability designates a "root" in the local file system of the
node.  Passing a file system to a domain results in the domain having access to
every file and subdirectory contained within it.

<h4>File</h4>

A file capability grants a domain access to a particular file in a file system
capability.  Passing a file to a domain grants it the ability to read, write,
and/or append to the file, depending on the permissions attached to the
capability.

<ul>
<li>File System - The file system capability that is the root for this file.
Defaults to the current working directory.
<li>Path - The location of the file, relative to the file system object.
</ul>

<h4>Clock</h4>

XXX This is likely to be removed soon, just use the system clock in the root
directory.

"""

print beesPageTemplate.header % config

print body

print beesPageTemplate.footer % config
